<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */

if ( ! function_exists( 'ultra_gym_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  ultra_gym 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function ultra_gym_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'ultra_gym_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'ultra_gym_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  ultra_gym 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function ultra_gym_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'ultra_gym_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if slider section is enabled.
 *
 * @since  ultra_gym 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultra_gym_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultra_gym_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if about section is enabled.
 *
 * @since  ultra_gym 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultra_gym_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultra_gym_theme_options[about_section_enable]' )->value() );
}


/**
 * Check if service section is enabled.
 *
 * @since  ultra_gym 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultra_gym_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultra_gym_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since  ultra_gym 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultra_gym_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'ultra_gym_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if blog section is enabled.
 *
 * @since  ultra_gym 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultra_gym_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultra_gym_theme_options[blog_section_enable]' )->value() );
}
