<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage ultra_gym
 * @since ultra_gym 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'ultra_gym_blog_section',
    array(
        'title'             => esc_html__( 'Blog','ultra-gym' ),
        'description'       => esc_html__( 'Blog Section options.', 'ultra-gym' ),
        'panel'             => 'ultra_gym_front_page_panel',
    )
);

// Blog content enable control and setting
$wp_customize->add_setting( 'ultra_gym_theme_options[blog_section_enable]',
    array(
        'default'           =>  $options['blog_section_enable'],
        'sanitize_callback' => 'ultra_gym_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Ultra_Gym_Switch_Control( $wp_customize, 'ultra_gym_theme_options[blog_section_enable]',
    array(
        'label'             => esc_html__( 'Blog Section Enable', 'ultra-gym' ),
        'section'           => 'ultra_gym_blog_section',
        'on_off_label'      => ultra_gym_switch_options(),
    ) 
) );

// Blog section sub title control and setting
$wp_customize->add_setting('ultra_gym_theme_options[blog_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
        'default'  => $options['blog_sub_title'],
    )
);

$wp_customize->add_control('ultra_gym_theme_options[blog_sub_title]',
    array(
        'label' => esc_html__('Section Sub Title', 'ultra-gym'),
        'section' => 'ultra_gym_blog_section',
        'type' => 'text',
        'active_callback' => 'ultra_gym_is_blog_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultra_gym_theme_options[blog_sub_title]',
        array(
            'selector'            => '#blog .section-header p.section-subtitle',
            'settings'            => 'ultra_gym_theme_options[blog_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'ultra_gym_blog_sub_title_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'ultra_gym_theme_options[blog_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'ultra_gym_theme_options[blog_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'ultra-gym' ),
        'section'           => 'ultra_gym_blog_section',
        'active_callback'   => 'ultra_gym_is_blog_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultra_gym_theme_options[blog_title]',
        array(
            'selector'            => '#blog .section-header h2.section-title',
            'settings'            => 'ultra_gym_theme_options[blog_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'ultra_gym_blog_title_partial',
        )
    );
}


// Add dropdown category setting and control.
$wp_customize->add_setting(  'ultra_gym_theme_options[blog_content_category]',
    array(
        'sanitize_callback' => 'ultra_gym_sanitize_single_category',
    )
) ;

$wp_customize->add_control( new Ultra_Gym_Dropdown_Taxonomies_Control( $wp_customize,'ultra_gym_theme_options[blog_content_category]',
    array(
        'label'             => esc_html__( 'Select Category', 'ultra-gym' ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym' ),
        'section'           => 'ultra_gym_blog_section',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'ultra_gym_is_blog_section_enable'
    ) 
) );


// Blog content setting
$wp_customize->add_setting('ultra_gym_theme_options[blog_post_read_more_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['blog_post_read_more_btn_label']

    )
);

$wp_customize->add_control('ultra_gym_theme_options[blog_post_read_more_btn_label]',
    array(
        'section'			=> 'ultra_gym_blog_section',
        'label'				=> esc_html__( 'Post Read More Button Label', 'ultra-gym' ),
        'type'          	=>'text',
        'active_callback'	=> 'ultra_gym_is_blog_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultra_gym_theme_options[blog_post_read_more_btn_label]',
        array(
            'selector'            => '#blog div.more-link a',
            'settings'            => 'ultra_gym_theme_options[blog_post_read_more_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'ultra_gym_blog_post_read_more_btn_label_partial',
        ) 
    );
}
